## What is a DOI?

A [DOI](http://www.doi.org//) (Digital Object Identifier) permanently identifies a digital resource.

For your research this means:

*     You can make any of your public data sets citable. You will get a permanent link to the data set you provide, your data will be hosted on the gin infrastructure.
*     You can also make your scripts, software, laboratory protocols citable by giving them a DOI and gaining credit for your work.

gin-doi is the G-Node Infrastructure DOI service. A service which archives your public repository and provides you with a DOI such that you can cite this data. gin-doi fulfills the DataCite standard which aims to:

*     Establish easier access to research data on the Internet.
*     Increase acceptance of research data as legitimate, citable contributions to the scholarly record.
*     Support data archiving that will permit results to be verified and re-purposed for future study.

You can find datasets already published with the gin-doi service at [http://doid.gin.g-node.org](http://doid.gin.g-node.org).

## Obtaining a DOI (Digital Object Identifier)

A [DOI](http://www.doi.org//) (Digital Object Identifier) permanently identifies a digital resource, allowing data sets or files to be made citable.

To make use of gin-doi, the G-Node Infrastructure DOI service, a valid DOI request file must be provided at the root of the repository you wish to create a DOI for.

An example file can be found [here](http://gin.g-node.org/G-Node/Info/src/master/datacite.yml). You can find datasets already published with the gin-doi service at [http://doid.gin.g-node.org](http://doid.gin.g-node.org).

Before submitting your DOI request, ensure that the Readme file for your repository is comprehensive and complete. This greatly helps anyone who wants to use your data in the future.

Consider including summaries of the repository contents and structure, information on how to download the data, a link to your repository allowing those viewing an archived file to access the possibly updated version, along with a list of related publications and licensing information. A good example can be found [here](https://web.gin.g-node.org/INT/multielectrode_grasp).

### Creating a DOI request file

The DOI request file must be written in the machine-readable YAML format and saved as "datacite.yml". It must be stored using [UTF-8](https://en.wikipedia.org/wiki/UTF-8) encoding. Text editors that do not store files as such by default (often the case when using Windows) should be instructed to do so. Once complete, the file should be uploaded to the root of your repository using git or the gin client.

Alternatively, our built-in text editor may be used to create the DOI request file. To do so, click the "New file" button from within your repository.

![NewFile](https://web.gin.g-node.org/G-Node/images_hideme/src/master/tutorials/DOI/NewFile.png)

The new file should be named "datacite.yml". After adding an appropriate commit message click "Commit Changes" at the bottom of the page to save.

![Editor](https://web.gin.g-node.org/G-Node/images_hideme/src/master/tutorials/DOI/Editor.png)

[yamlint.com](http://www.yamllint.com/) can be used to verify whether a YAML file is formally correct.

Once uploaded or saved to the root of a repository, a valid file will be rendered below the Readme section in the repository overview.
### Structuring the DOI request file

The datacite.yml file must contain the following entries:

```
authors 
title 
description 
keywords 
license
```

These entries may also be used to provide additional information:

```
references
funding
```

Entries are specified by providing the corresponding lowercase keyword (authors, title, etc.) followed by a colon and contents formatted as described here and seen in the [example file](http://gin.g-node.org/G-Node/Info/src/master/cloudberry.yml).
#### authors

Authors are the main researchers involved in working on the data, or the authors of the publication in order of priority.

A first and last name, either personal or corporate/institutional, is required. Additionally, affiliation and id (digital identifier, e.g., ORCID) may be provided. Please enter the authors as list items, each item indented and prefixed with -, each of the author keywords indented as shown below.

```
authors:
 -         
  firstname: "GivenName1"         
  lastname: "FamilyName1"         
  affiliation: "Affiliation1"         
  id: "AuthorID1 (e.g. ORCID)"       
 -         
  firstname: "GivenName2"         
  lastname: "FamilyName2"         
  affiliation: "Affiliation2"       
 -         
  firstname: "GivenName3"         
  lastname: "FamilyName3"
```

#### title

The title is the descriptive name of the data set to be published. Linebreaks may not be used in the title field.

`title: "Example Title"`

#### description

The description contains extended information about your dataset. Linebreaks may be used as long as indentation is maintained.

```
description:     
 Example description       
 that can contain linebreaks       
 but has to maintain indentation.
```

#### keywords

The keywords entry should be used to list terms the dataset is associated with. As many keywords as needed to appropriately characterize the dataset may be entered, with each one being on a new line, indented, and prefixed with -.

```
keywords:       
 - Neuroscience       
 - Electrophysiology 
```

#### license

The license entry specifies the license under which the dataset will be published. Examples of open licenses are

```
CC0 (http://creativecommons.org/publicdomain/zero/1.0/) 
CC-BY (http://creativecommons.org/licenses/by/4.0/) 
```

More licenses can be found [here](https://creativecommons.org/licenses/).

Please provide both a license name and a url to the license, both indented as shown in the example below. In addition, a LICENSE file should be added to the repository. The license file can either be selected when creating your repository or uploaded afterward.

```
license:       
 name: "CC0"       
 url: "http://creativecommons.org/publicdomain/zero/1.0" 
```

#### references

References are resources associated with the data set, such as a research article that is based on the data. In addition to the name, please provide the relation to the dataset and, if possible, a digital identifier (e.g., DOI).

For reftype, the following relations may be used. Further valid types can be found [here](https://schema.datacite.org/meta/kernel-4).

```
IsCitedBy
IsSupplementTo
IsReferencedBy
IsPartOf
```

Please enter the references as list items, each item indented and prefixed with -, each of the keywords indented as shown below.

```
references:       
 -         
  doi: "10.xxx/yyyy"         
  reftype: "IsPartOf"         
  name: "PublicationName"       

 -         
  doi: "10.xxx/zzzz"         
  reftype: "IsSupplementTo"         
  name: "PublicationName" 
```

#### funding

Funding is a list of items to indicate any funding received to produce the referenced dataset. Funder name and grant number should be specified and separated by a comma. Each item should be on a new line, indented, and prefixed with -.

```
funding:       
 - "DFG, DFG.12345"       
 - "EU, EU.12345"
``` 

### Requesting a DOI

Once a valid DOI request file named "datacite.yml" has been uploaded to the root of a public repository, a preview of the contents will be rendered below the Readme section in the repository overview. A DOI may now be requested by clicking the "DOIfy" button.

![DOIfy](https://web.gin.g-node.org/G-Node/images_hideme/src/master/tutorials/DOI/DOIfy.png)

The DOI request file will be automatically checked for formatting and encoding errors. A preview is also displayed, allowing a final check for any mistakes. Once you have ensured that your DOI request file is correct, click the "Doify Now" button to submit your request. 

Please note that all data contained in your repository will be archived for DOI registration. Any private files should thus be removed before submitting a DOI request.

![Preview](https://web.gin.g-node.org/G-Node/images_hideme/src/master/tutorials/DOI/Preview.png) 
